==> igniteui-react-16.16.2.tgz: package/esm5/lib/Icon.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
/**
 * @hidden
 */
var Icon = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Icon, _super);
    function Icon() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(Icon.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Icon.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.b.d = this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Icon.prototype, "h", {
        get: function () {
            var ret_ = this.c.c("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Icon.prototype, "g", {
        get: function () {
            var ret_ = this.c.c("collection");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("collection", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Icon.prototype, "d", {
        get: function () {
            var ret_ = this.c.c("mirrored");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("mirrored", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Icon.prototype, "a", {
        get: function () {
            var ret_ = this.c.c("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, EnumUtil.parse(SizableComponentSize_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.c.i("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Icon.prototype.i = function () {
        this.nativeElement.connectedCallback();
    };
    Icon.prototype.j = function () {
        this.nativeElement.disconnectedCallback();
    };
    Icon.prototype.k = function (a, b, c) {
        this.nativeElement.registerIcon(a, b, c);
    };
    Icon.prototype.l = function (a, b, c) {
        this.nativeElement.registerIconFromText(a, b, c);
    };
    Icon.$t = markType(Icon, 'Icon', BaseElement.$);
    return Icon;
}(BaseElement));
export { Icon };

==> igniteui-react-18.6.0.tgz: package/esm5/lib/Icon.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
/**
 * @hidden
 */
var Icon = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Icon, _super);
    function Icon() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(Icon.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Icon.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.b.o = this.e;
        },
        enumerable: false,
        configurable: true
    });
    Icon.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Icon.prototype, "h", {
        get: function () {
            var ret_ = this.c.n("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Icon.prototype, "g", {
        get: function () {
            var ret_ = this.c.n("collection");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("collection", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Icon.prototype, "d", {
        get: function () {
            var ret_ = this.c.n("mirrored");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("mirrored", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Icon.prototype, "a", {
        get: function () {
            var ret_ = this.c.n("size");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.c.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.c.v("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Icon.prototype.i = function () {
        this.nativeElement.connectedCallback();
    };
    Icon.prototype.j = function () {
        this.nativeElement.disconnectedCallback();
    };
    Icon.prototype.k = function (a, b, c) {
        this.nativeElement.registerIcon(this.c.i(a), this.c.i(b), this.c.i(c));
    };
    Icon.prototype.l = function (a, b, c) {
        this.nativeElement.registerIconFromText(this.c.i(a), this.c.i(b), this.c.i(c));
    };
    Icon.$t = markType(Icon, 'Icon', BaseElement.$);
    return Icon;
}(BaseElement));
export { Icon };
